@@ -4,7 +4,7 @@
 # SPDX-License-Identifier: MIT
 
 """
-`adafruit_ds3231` - DS3231 Real Time Clock module
+`adafruit_ds3231`
 =================================================
 CircuitPython library to support DS3231 Real Time Clock (RTC).
 
@@ -26,12 +26,14 @@ Implementation Notes
 
 **Software and Dependencies:**
 
-* Adafruit CircuitPython firmware for the ESP8622 and M0-based boards:
-  https://github.com/adafruit/circuitpython/releases
+* Adafruit CircuitPython firmware for the supported boards:
+  https://circuitpython.org/downloads
 
 * Adafruit's Register library: https://github.com/adafruit/Adafruit_CircuitPython_Register
+
 * Adafruit's Bus Device library: https://github.com/adafruit/Adafruit_CircuitPython_BusDevice
 
+
 **Notes:**
 
 #. Milliseconds are not supported by this RTC.
@@ -49,7 +51,42 @@ __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_DS3231.git"
 
 # pylint: disable-msg=too-few-public-methods
 class DS3231:
-    """Interface to the DS3231 RTC."""
+    """Interface to the DS3231 RTC.
+
+    :param ~busio.I2C i2c: The I2C bus the device is connected to
+
+    **Quickstart: Importing and using the device**
+
+        Here is an example of using the :class:`DS3231` class.
+        First you will need to import the libraries to use the sensor
+
+        .. code-block:: python
+
+            import time
+            import board
+            import adafruit_ds3231
+
+        Once this is done you can define your `board.I2C` object and define your sensor object
+
+        .. code-block:: python
+
+            i2c = board.I2C()  # uses board.SCL and board.SDA
+            rtc = adafruit_ds3231.DS3231(i2c)
+
+        Now you can give the current time to the device.
+
+        .. code-block:: python
+
+            t = time.struct_time((2017, 10, 29, 15, 14, 15, 0, -1, -1))
+            rtc.datetime = t
+
+        You can access the current time accessing the :attr:`datetime` attribute.
+
+        .. code-block:: python
+
+            current_time = rtc.datetime
+
+    """
 
     lost_power = i2c_bit.RWBit(0x0F, 7)
     """True if the device has lost power since the time was set."""
